ALIVE_UNWELL = "alive_unwell"
APPT = "appt"
APPT_OTHER = "other_routine_appt"
ART_CONTINUED = "art_continued"
ART_STOPPED = "art_stopped"
BLOOD_RESULTS_CHEM_ACTION = "abnormal-blood-results-chem"
DECREASED = "decreased"
FOLLOWUP_ACTION = "follow_up"
FOLLOWUP_EXAMINATION_ACTION = "followup-examination-ae"
IF_ADMITTED_COMPLETE_REPORTS = "If YES, complete Hospitalization and AE Initial reports."
IF_NO_SPECIFY_REASON = "If NO, please specify reason ..."
IF_YES_COMPLETE_AE = "If YES, complete AE Initial report."
LOW_EGFR_ACTION = "low-egfr"
LP_ACTION = "submit_lp_result"
PRESENT_REINFORCEMENT = "present_reinforcement"
PRESENT_WITH_REINFORCEMENT = "present_with_reinforcement"
REDUCED = "reduced"
SX_ACTION = "signs_and_symptoms"
VITAL_SIGNS_ACTION = "vital_signs"
